
#ifndef GCC_MAIv2DLL_h
#define GCC_MAIv2DLL_h

typedef unsigned long	ulong;
typedef unsigned char	uchar;
typedef unsigned short	ushort;
typedef unsigned int	uint;
typedef unsigned long long u64;

typedef long long int __int64;


typedef void (*MAI_DEVICELISTCHANGED_CALLBACK) ( unsigned int /*  number of new found devices */,
int*		  /*  instance Numbers of the new found devices */ ,
unsigned int /*  number of missing devices */,
int*		  /*  instance Numbers of the missing devices */ )  __attribute__((stdcall));




////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für den Oversampling Modus eines AD Messkanals.  </summary>
/// <summaryE>	possible values for the oversampling mode of an  AD measurement channel.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eOversampling	{ oversamplingDISABLED, oversampling2x, oversampling4x, oversampling8x, oversampling16x };

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für den Gainfaktor eines AD Messkanals.  </summary>
/// <summaryE>	possible values for the gain factor of an AD measurement channel.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eGain			{ gainDisabled, gain2x, gain4x, gain8x };

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für die Polarität eines AD Messkanals.  </summary>
/// <summaryE>	possible values for an AD measurement channel's polarity.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eBipolar		{ polUNIPOLAR, polBIPOLAR };

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für den Parameter PartBlock.  </summary>
/// <summaryE>	possible values for the PartBlock parameter.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum ePartBlock		{ partONLYFULLBLOCKS, partPARTBLOCK };

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für den Parameter SkipData.  </summary>
/// <summaryE>	possible values for the SkipData parameter.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eSkipData		{ skipGETCAPTUREDVALUES, skipSKIPCAPTUREDVALUES };

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für den Streaming Modus.  </summary>
/// <summaryE>	possible values for the streaming mode.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eStreamingMode { smOFF, smON };

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Zähler Modi.  </summary>
/// <summaryE>	counter modes.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////

enum eCounterMode	{       cmIMPULSECOUNTER      = 0,
                            cmPERIODCOUNTER       = 1, 
                            cmPULSWIDTHCOUNTER    = 2, 
                            cmFREQUENCYCOUNTER    = 3,
                            cmUPDOWNCOUNTER       = 4,
                            cmINCREMENTALCOUNTER  = 5,
                            cmINCREMENTALEXTTIME  = 6,
                            cmINCREMENTALEXTFLOW  = 7 };

enum eCounterModesList  {   cmlIMPULSECOUNTER     = 1 << cmIMPULSECOUNTER,
                            cmlPERIODCOUNTER      = 1 << cmPERIODCOUNTER, 
                            cmlPULSWIDTHCOUNTER   = 1 << cmPULSWIDTHCOUNTER, 
                            cmlFREQUENCYCOUNTER   = 1 << cmFREQUENCYCOUNTER,
                            cmlUPDOWNCOUNTER      = 1 << cmUPDOWNCOUNTER,
                            cmlINCREMENTALCOUNTER = 1 << cmINCREMENTALCOUNTER,
                            cmlINCREMENTALEXTTIME = 1 << cmINCREMENTALEXTTIME,
                            cmlINCREMENTALEXTFLOW = 1 << cmINCREMENTALEXTFLOW };

enum eCounterParam	{   ctparamPRESETVALUE,
                        ctparamIMPULSEDIRECTION, 
                        ctparamSIGNALEDGE, 
                        ctparamFREQUENCYCOUNTERRESOLUTION,
                        ctparamSOFTWARERESET,
                        ctparamHARDWARERESETMODE,
                        ctparamHARDWARERESETEDGE,
                        ctparamINTERPOLATIONMODE,
                        ctparamINCREMENTALEXTTIMERESOLUTION };

enum eCounterParamsList	{   ctplPRESETVALUE                   = 1 << ctparamPRESETVALUE,
                            ctplIMPULSEDIRECTION              = 1 << ctparamIMPULSEDIRECTION, 
                            ctplSIGNALEDGE                    = 1 << ctparamSIGNALEDGE, 
                            ctplFREQUENCYCOUNTERRESOLUTION    = 1 << ctparamFREQUENCYCOUNTERRESOLUTION,
                            ctplSOFTWARERESET                 = 1 << ctparamSOFTWARERESET,
                            ctplHARDWARERESETMODE             = 1 << ctparamHARDWARERESETMODE,
                            ctplHARDWARERESETEDGE             = 1 << ctparamHARDWARERESETEDGE,
                            ctplINTERPOLATIONMODE             = 1 << ctparamINTERPOLATIONMODE,
                            ctplINCREMENTALEXTTIMERESOLUTION  = 1 << ctparamINCREMENTALEXTTIMERESOLUTION };

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für den externen Trigger Modus.  </summary>
/// <summaryE>	possible values for external trigger mode.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eTrigger		{ trigDISABLED, trigEXTERN_TRIGGER, trigEXTERN_CLOCK };

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für die externe Trigger Signalflanke.  </summary>
/// <summaryE>	possible values for external trigger's signal edge.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eExternEdge	{ tedgeFALLING_EDGE, tedgeRISING_EDGE };


////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für den Typ der FFT Analyse.  </summary>
/// <summaryE>	possible values for the FFT spectrum's type.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eFFT_Type {	fftAbsolute	=0,
    /// Root Mean Square (Effektivwert).
    fftRMS 	    =1,
    ///  Quadrat der Effektivwerte.
    fftPower 	=2,
    /// Phasenspektrum.
    fftPhase 	=3};

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für die Anzahl von Stützstellen bei der Onlie FFT Analyse.  </summary>
/// <summaryE>	possible values for the number of FFT points.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eFFT_Size {
    /// <summary> 512 Stützstellen.  </summary>
    /// <summaryE> 512 points.  </summaryE>
    fft_s512  =  0,
    /// <summary> 1024 Stützstellen.  </summary>
    /// <summaryE> 1024 points.  </summaryE>
    fft_s1024 =  1,
    /// <summary> 2048 Stützstellen.  </summary>
    /// <summaryE> 2048 points.  </summaryE>
    fft_s2048 =  2,
    /// <summary> 4096 Stützstellen.  </summary>
    /// <summaryE> 4096 points.  </summaryE>
    fft_s4096 =  3
};
////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für den Typ eines Online Triggers.  </summary>
/// <summaryE>	possible values for the type of an online trigger.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eTrigger_Type {
    /// <summary> Maximum.  </summary>
    /// <summaryE> maximum.  </summaryE>
    trigMax						=0,
    /// <summary> Minumum.  </summary>
    /// <summaryE> minumum.  </summaryE>
    trigMin						=1,
    /// <summary> unterhalb einer Schwelle.  </summary>
    /// <summaryE> on threshold underrun.  </summaryE>
    trigUnterSchwelle 			=2,
    /// <summary> oberhalb einer Schwelle.  </summary>
    /// <summaryE>  on threshold overrun.  </summaryE>
    trigUeberSchwelle 			=3,
    /// <summary> in einem Fenster.  </summary>
    /// <summaryE> inside a window.  </summaryE>
    trigFenster					=4,
    /// <summary> unterhalb einer Gradientensteigung.  </summary>
    /// <summaryE> on gradient slope underrun.  </summaryE>
    trigUnterGradientensteigung	=5,
    /// <summary> oberhalb einer Gradientensteigung.  </summary>
    /// <summaryE> on gradient slope overrun.  </summaryE>
    trigUeberGradientensteigung =6,
    /// <summary> in einem Gradientenfenster.  </summary>
    /// <summaryE> inside a gradient window.  </summaryE>
    trigGradientenfenster		=7
};

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	 Entwurfsmethoden des PID Controller-Algorithmus  </summary>
/// <summaryE>	 design method of the PID controller algorithm  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////

enum  ePIDControllerType  {
    /// <summary> Integralalgorithmus linke Intervallgrenze.  </summary>
    /// <summaryE> lower limit of the integral integal.  </summaryE>
    pidPID1			= 0,
    /// <summary> Integralalgorithmus rechte Intervallgrenze.  </summary>
    /// <summaryE> upper limit of the integral.  </summaryE>
    pidPID2		    = 1,
    /// <summary> Integralalgorithmus Trapetznäherung.  </summary>
    /// <summaryE> trapezoid.  </summaryE>
    pidPID3		    = 2,
    
};
////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Legt die Charakteristik eines digitalen Filters fast.  </summary>
/// <summaryE>	digital filters characteristics.  </summaryE>
///
////////////////////////////////////////////////////////////////////////////////////////////////////

enum  eFilterType  {
    /// <summary> Tiefpass.  </summary>
    /// <summaryE> low pass.  </summaryE>
    ftLOWPASS  = 0,
    /// <summary> Hochpass.  </summary>
    /// <summaryE> high pass.  </summaryE>
    ftHIGHPASS = 1,
    /// <summary> Bandpass.  </summary>
    /// <summaryE> band pass.  </summaryE>
    ftBANDPASS = 2,
    /// <summary> Bandstop.  </summary>
    /// <summaryE> band stop.  </summaryE>
    ftBANDSTOP = 3,
};

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	IIR Filter Designmethode  </summary>
/// <summaryE>	IIR filter design method  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum  eIIRFilterDesign  {
    /// <summary> Butterworth.  </summary>
    /// <summaryE> Butterworth.  </summaryE>
    iirBUTTERWORTH                = 0,
    /// <summary> Tschebytschow 1.  </summary>
    /// <summaryE> Tschebytschow 1.  </summaryE>
    iirCHEBYSHEV_T1               = 1,
    /// <summary> Tschebytschow 2.  </summary>
    /// <summaryE> Tschebytschow 2.  </summaryE>
    iirCHEBYSHEV_T2               = 2,
    /// <summary> Elliptisch (Cauer).  </summary>
    /// <summaryE> Elliptisch (Cauer).  </summaryE>
    iirELLIPTIC                   = 3,
    /// <summary> Bessel.  </summary>
    /// <summaryE> Bessel.  </summaryE>
    iirBESSEL                     = 4,
};

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Mögliche Werte für den Typ der FIR Fensterfunktion.  </summary>
/// <summaryE>	possible values for the FIR window function.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eFIRWindowFunction {
    
    /// <summary> Rechteck.  </summary>
    firwinRectangular         = 0,
    /// <summary> Hanning (eg. Hann, ...).  </summary>
    firwinHanning             = 1,
    /// <summary> Hamming (eg. Hamm, ...).  </summary>
    firwinHamming             = 2,
    /// <summary> Blackman.  </summary>
    firwinBlackman            = 3,
    /// <summary> Kaiser.  </summary>
    firwinKaiser              = 4,
    /// <summary> Bartlett.  </summary>
    firwinBartlett            = 5,
    /// <summary> Dolph-Tschebytschow (eg. Dolph-Tschebytescheff,  Dolph-Chebycheff...).  </summary>
    firwinDolph_Tschebytschow = 6,
    /// <summary> Dreieck.  </summary>
    firwinTriangular          = 7,
    /// <summary> Blackman-Harris.  </summary>
    firwinBlackman_Harris		= 8,
    /// <summary> Blackman-Nuttall.  </summary>
    firwinBlackman_Nuttall    = 9,
    /// <summary> Flat Top (Flache Spitze).  </summary>
    firwinFlat_Top			= 10,
};

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Bitnummern der verscheidenen Software Erweiterungen.  </summary>
/// <summaryE>	bit numbers of the existing software extensions.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eSWExtensionsBitNumber {
    /// <summary> Online_FFT  </summary>
    swxOnline_FFT					= 0,
    /// <summary> Online_Filter.  </summary>
    swxOnline_Filter				= 1,
    /// <summary> Online_PID.  </summary>
    swxOnline_PID					= 2,
    /// <summary> Online_Linearisierung.  </summary>
    swxOnline_Linearisierung		= 3,
    /// <summary> OnboardFunktionsgenerator.  </summary>
    swxOnboardFunktionsgenerator	= 4,
    /// <summary> Wabco_Projekt.  </summary>
    swxWabco_Projekt				= 9,
    /// <summary> Airbag_Pruefstand.  </summary>
    swxAirbag_Pruefstand			= 14,
    /// <summary> UpDown_Card.  </summary>
    swxUpDown_Card					= 15,
    /// <summary> Extended_Stoptrigger.  </summary>
    swxExtended_Stoptrigger		= 16
};

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Bitnummern der verscheidenen Hardware Erweiterungen.  </summary>
/// <summaryE>	bit numbers of the existing hardware extensions.  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
enum eHWExtensionsBitNumber {
    /// <summary> Zaehlerupgrade.  </summary>
    hwxZaehlerupgrade						= 0,
    /// <summary> UpDown_Counter.  </summary>
    hwxUpDown_Counter						= 1,
    /// <summary> PWM_Ausgabe.  </summary>
    hwxPWM_Ausgabe							= 2,
    /// <summary> PWM_Karte.  </summary>
    hwxPWM_Karte							= 3,
    /// <summary> DA_Wandler.  </summary>
    hwxDA_Wandler							= 4,
    /// <summary> MultiplexerUeberspannungsschutz.  </summary>
    hwxMultiplexerUeberspannungsschutz		= 5,
    /// <summary> DualWandler.  </summary>
    hwxDualWandler							= 8,
    /// <summary> Zeitstempel.  </summary>
    hwxZeitstempel							= 9,
    /// <summary> TTL_Bitweise.  </summary>
    hwxTTL_Bitweise						= 10,
    /// <summary> Coprozessor_56307.  </summary>
    hwxCoprozessor_56307					= 11,
    /// <summary> Coprozessor_56311.  </summary>
    hwxCoprozessor_56311					= 12,
    /// <summary> Inkrementalzaehler. .  </summary>
    hwxInkrementalzaehler  			    = 13,
    /// <summary> RegeneratorAutomotiv.  </summary>
    hwxRegeneratorAutomotiv				= 14,
    /// <summary> MH_Zaehlererweiterung.  </summary>
    hwxMH_Zaehlererweiterung				= 15,
    /// <summary> SSI_Schnittstelle.  </summary>
    hwxSSI_Schnittstelle					= 16,
    /// <summary> Thermoelementanschluss_8Kanal.  </summary>
    hwxThermoelementanschluss_8Kanal		= 17,
    /// <summary> 32Bit_Zaehler.  </summary>
    hwx32Bit_Counter						= 18,
    /// <summary> ICP_Einspeisung.  </summary>
    hwxICP_Einspeisung						= 19
};

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <summary>	Modus der IEPE Ausgabe  </summary>
/// <summaryE>	IEPE powering mode  </summaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////

enum  eIEPEMode  {
    /// <summary> DC, Massebezogen, IEPE  inaktiv (default).  </summary>
    /// <summaryE>	DC, SE, IEPE_off (default) </summaryE>
    iepeDC_SE_IEPE_off		= 0,
    /// <summary> DC, Differenz, IEPE  inaktiv.  </summary>
    /// <summaryE>	DC, Differencial, IEPE_off  </summaryE>
    iepeDC_Diff_IEPE_off	= 1,
    /// <summary> AC, Differenz, IEPE  inaktiv.  </summary>
    /// <summaryE>	AC, Differencial, IEPE_off  </summaryE>
    iepeAC_SE_IEPE_off		= 2,
    /// <summary> AC, Massebezogen IEPE  aktiv.  </summary>
    /// <summaryE>	AC, Differencial, IEPE_on  </summaryE>
    iepeAC_SE_IEPE_on	    = 3
    
};

#define MAIV2DLL_EXPORT	        int
#define MAIV2DLL_EXPORT_CHAR    const char*


#ifdef __cplusplus
extern "C" {
#endif

////////////////////////////////////////////////////////////////////////////////////////////////////
/// <category>	AD-Funktionen. </category>
/// <categoryE>	AD functions. </categoryE>
///
///
/// <filesummary>	zur Steuerung bzw. Messung der AD Kanäle stehen die folgenden Funktionen zur Verfügung:. </filesummary>
/// <filesummaryE>	for controlling and measuring AD Channels these functions are available: </filesummaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////

MAIV2DLL_EXPORT		AD_ClearChannelList(uint nInstance);
MAIV2DLL_EXPORT		AD_AddChannelToList(uint nInstance, uint nChannel, uint nOversampling, uint nGain, uint nBipolar);
MAIV2DLL_EXPORT		AD_GetChannelListSize(uint nInstance, uint * nCLSize);
MAIV2DLL_EXPORT		AD_ReadSingleValue(uint nInstance, uint nChannel, uint nOversampling, uint nGain, uint nBipolar, int * nRawValue);
MAIV2DLL_EXPORT		AD_ReadSingleValueExt(uint nInstance, uint nChannel, uint nOversampling, uint nGain, uint nBipolar, int * nRawValue, double * dVoltage, float * fVoltage);
MAIV2DLL_EXPORT		AD_ReadSingleVoltage(uint nInstance, uint nChannel, uint nOversampling, uint nGain, uint nBipolar, double * bVoltage);
MAIV2DLL_EXPORT		AD_SetFrequency(uint nInstance, double fFrequency);
MAIV2DLL_EXPORT 	AD_GetFrequency(uint nInstance, double * fFrequency);
MAIV2DLL_EXPORT 	AD_ReadLastBurst(uint nInstance, int RawData[], double Value[], uint * nNumberOfValues);
MAIV2DLL_EXPORT 	AD_ReadData(uint nInstance, uint nChannelListEntry, int RawData[], double Value[], uint * nValuesPerChannel, uint bPartBlock, uint bSkipData);
MAIV2DLL_EXPORT     AD_ReadDataExt(uint nInstance, uint nChannelListEntry, int pRawData[], double pDoubleValues[], float pFloatValues[], uint * nValuesPerChannel, uint bPartBlock, __int64* AODateTimeT0, double* AODateTimeDeltaT);
MAIV2DLL_EXPORT 	AD_ReadBinaryData(uint nInstance, uchar BinaryData[], uint * nLength);
MAIV2DLL_EXPORT		AD_GetStreamPipeLevel(uint nInstance, double * fStreamPipeLevel);
MAIV2DLL_EXPORT 	AD_GetNumberOfValues(uint nInstance, uint * nNumberOfValues);
MAIV2DLL_EXPORT 	AD_StartMeasure(uint nInstance);
MAIV2DLL_EXPORT 	AD_StopMeasure(uint nInstance);
MAIV2DLL_EXPORT 	AD_SetIEPE(uint nInstance, uint nChannel,uint nIEPEMode, uint bGain);
MAIV2DLL_EXPORT 	AD_SetIEPEOnAudioModul(uint nInstance, uint nChannel,uint bIEPEOn, uint bDCOn, uint bCurrentSourceOn, uint bGainOn);
MAIV2DLL_EXPORT 	AD_SetEventToBeRaisedWhenNumberOfBurstsAvailable(uint nInstance, void* hEventHandle, uint nNumberOfBursts);
MAIV2DLL_EXPORT		AD_Audio_SetHPFilter(uint nInstance,uint nChannel, uint bFilterOn);
MAIV2DLL_EXPORT     AD_Audio_SetHPFilterResponse(uint nInstance,  uint nADCNr, uint bLowGroupDelayResponseOn);

MAIV2DLL_EXPORT 	AD_ResetIEPE(uint nInstance);
MAIV2DLL_EXPORT 	AD_GetIEPEType(uint nInstance);






////////////////////////////////////////////////////////////////////////////////////////////////////
/// <category>	CT-Funktionen. </category>
/// <categoryE>	CT functions. </categoryE>
///
///
/// <filesummary>	zur Steuerung bzw. Messung der CT Kanäle stehen die folgenden Funktionne zur Verfügung:. </filesummary>
/// <filesummaryE>	for controlling and measuring CT Channels these functions are available: </filesummaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
MAIV2DLL_EXPORT CT_ClearChannelList(uint nInstance);
MAIV2DLL_EXPORT CT_AddChannelToList(uint nInstance, uint nChannel, bool bToADChannellist);
MAIV2DLL_EXPORT CT_GetChannelListSize(uint nInstance, uint * nCLSize);
MAIV2DLL_EXPORT CT_SetFrequency(uint nInstance, double fFreqency);
MAIV2DLL_EXPORT CT_GetFrequency(uint nInstance, double * fFrequency);
MAIV2DLL_EXPORT CT_UpDownCounter(uint nInstance, uint nChannel, uint nPresetValue, uint nUpDown, uint nEdge, uint nSoftwareReset);
MAIV2DLL_EXPORT CT_ScaleData(uint nInstance, uint nChannelListEntry, int* pInBuffer, double* pOutBuffer,uint nNumberOfValues, int* ARFirstLastValue);
MAIV2DLL_EXPORT CT_ReadData(uint nInstance, uint nChannelListEntry, uint* pBuffer, uint * nNumberOfValues, uint bPartBlock, uint bSkipData);
MAIV2DLL_EXPORT CT_ReadDataExt(uint nInstance, uint nChannelListEntry, uint pBuffer[], uint * nNumberOfValues, uint bPartBlock, __int64* AODateTimeT0, double* AODateTimeDeltaT);
MAIV2DLL_EXPORT CT_ReadSingleValue(uint nInstance, uint nChannel, uint * SingleValue);
MAIV2DLL_EXPORT CT_GetStreamPipeLevel(uint nInstance, double * fStreamPipeLevel);
MAIV2DLL_EXPORT CT_GetNumberOfValues(uint nInstance, uint * nNumberOfValues);
MAIV2DLL_EXPORT CT_StartMeasure(uint nInstance);
MAIV2DLL_EXPORT CT_StopMeasure(uint nInstance);

MAIV2DLL_EXPORT CT_GetIncrementalCounterDirections(uint nInstance, uint* nDirectionValue);

MAIV2DLL_EXPORT CT_SetCounterParameter(uint nInstance, uint nChannelListEntry, uint eCOUNTERPARAMETER, uint nParameterValue);
MAIV2DLL_EXPORT CT_GetCounterParameter(uint nInstance, uint nChannelListEntry, uint  eCOUNTERPARAMETER, uint*  nParameterValue);
MAIV2DLL_EXPORT CT_GetCounterParametersForMode(uint nInstance, uint  eCOUNTERMODE, uint* AvailableCounterParameters);
MAIV2DLL_EXPORT CT_GetCounterParameterBoundaries(uint nInstance, uint eCOUNTERPARAMETER, uint* nMinValue  , uint*  nMaxValue);

MAIV2DLL_EXPORT CT_GetAvailableCounterModes(uint nInstance, uint nChannel,  uint* eCOUNTERMODES);

MAIV2DLL_EXPORT CT_SetCounterMode(uint nInstance, uint nChannelListEntry,  uint  eCOUNTERMODE);
MAIV2DLL_EXPORT CT_GetCounterMode(uint nInstance, uint nChannelListEntry,  uint* eCOUNTERMODE);


// Deprecated ConterMode Functions (may be removed in future versions):
MAIV2DLL_EXPORT CT_ImpulseCounter(uint nInstance, uint nChannel, uint nPresetValue, uint nUpDown, uint nEdge);
MAIV2DLL_EXPORT CT_FrequencyCounter(uint nInstance, uint nChannel, uint nResolution, uint nEdge, uint nEachPeriod);
MAIV2DLL_EXPORT CT_PeriodCounter(uint nInstance, uint nChannel, uint nResolution, uint nEdge, uint nEachPeriod);
MAIV2DLL_EXPORT CT_PulswidthCounter(uint nInstance, uint nChannel, uint nResolution, uint nEdge, uint nEachPeriod);
MAIV2DLL_EXPORT CT_IncrementalCounter(uint nInstance, uint nChannel, uint nResolution, uint nEdge, uint nSoftwareReset, uint nHardwareReset, uint nHWResetEdge, uint nInterpolation);
MAIV2DLL_EXPORT CT_IncrementalCounterExtensionTime(uint nInstance, uint nChannel, uint nResolution);
MAIV2DLL_EXPORT CT_IncrementalCounterExtensionFlow(uint nInstance, uint nChannel);





////////////////////////////////////////////////////////////////////////////////////////////////////
/// <category>	DA-Funktionen. </category>
/// <categoryE>	DA functions. </categoryE>
///
///
/// <filesummary>	zur Steuerung bzw. Messung der DA Kanäle stehen die folgenden Funktionne zur Verfügung:. </filesummary>
/// <filesummaryE>	for controlling and measuring DA Channels these functions are available: </filesummaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
MAIV2DLL_EXPORT DA_SetRange(uint nInstance, uint nRange);
MAIV2DLL_EXPORT DA_ClearChannelList(uint nInstance);
MAIV2DLL_EXPORT DA_AddChannelToList(uint nInstance, uint nChannel);
MAIV2DLL_EXPORT DA_GetChannelListSize(uint nInstance, uint * nCLSize);
MAIV2DLL_EXPORT DA_SetFrequency(uint nInstance, double fFrequency);
MAIV2DLL_EXPORT DA_StartOutput(uint nInstance);
MAIV2DLL_EXPORT DA_StopOutput(uint nInstance);
MAIV2DLL_EXPORT	DA_WriteChannelRaw(uint nInstance, uint nChannel, int RawValue);
MAIV2DLL_EXPORT	DA_WriteChannelVoltage(uint nInstance, uint nChannel, double VoltageValue);
MAIV2DLL_EXPORT DA_WriteRawData(uint nInstance, uint nChannelListEntry, int pBuffer[], uint * nLength, uint bPartBlock);
MAIV2DLL_EXPORT DA_WriteScaledData(uint nInstance, uint nChannelListEntry, double fScaledValues[], uint * nLength, uint bPartBlock);
MAIV2DLL_EXPORT DA_GetFifoState(uint nInstance, uint nChannel, uint * nNumberOfValues);
MAIV2DLL_EXPORT DA_Audio_SetMonauralMode(uint nInstance, uint bLoopbackModeOn);
MAIV2DLL_EXPORT DA_Audio_SetADLoopbackMode(uint nInstance, uint bLoopbackModeOn);





////////////////////////////////////////////////////////////////////////////////////////////////////
/// <category>	Device Funktionen. </category>
/// <categoryE>	device functions. </categoryE>
///
///
/// <filesummary>	zur Steuerung der nicht kanaltyp-spezifischen Kartenfunktionen stehen diese Funktionen zur Verfügung: </filesummary>
/// <filesummaryE>	for controlling the devices non channel dependent features these functions are available: </filesummaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////

// general functions
MAIV2DLL_EXPORT		ClearAllChannelLists(uint nInstance);
MAIV2DLL_EXPORT     ResetDevice(uint nInstance);
MAIV2DLL_EXPORT		LoadFirmware(uint nInstance);
MAIV2DLL_EXPORT		StartMeasure(uint nInstance);
MAIV2DLL_EXPORT		StopMeasure(uint nInstance);
MAIV2DLL_EXPORT		SetStreamingMode(uint nInstance, uint nStreamingMode);
MAIV2DLL_EXPORT		SetRunningMode(uint nInstance, uint MasterSlave);
MAIV2DLL_EXPORT		SetRunningModeEx(uint nInstance, uint MasterSlave, bool AIMultipleMastersAllowed);
MAIV2DLL_EXPORT		EnableSoftwareClock(uint nInstance, uint AIFetchADDataInUserMode);
MAIV2DLL_EXPORT		ConfigCard(uint nInstance, uint TriggerExtern, uint ExternEdge, uint DifferenzMode, uint p4);
MAIV2DLL_EXPORT		SetGlobalTriggerValues(uint nInstance, uint nPreTrigger, uint nPostTrigger, uint nWaitForStartTrigger);
MAIV2DLL_EXPORT		ConfigMeasure(uint nInstance);
MAIV2DLL_EXPORT		IdentifierDevice(uint nInstance);
MAIV2DLL_EXPORT		IsUSBHighSpeed(uint nInstance, uint * IsUSBHighSpeed);

// remoteDevice Funktionnen
MAIV2DLL_EXPORT		ConnectRemoteDevice(uint* nInstance, char* sIPAdress, uint nTCPPort, int nUDPINPort, bool* bIsNewInDevicelist);
MAIV2DLL_EXPORT		DisconnectRemoteDevice(uint nInstance);


// Eigenschaften der Karte
MAIV2DLL_EXPORT_CHAR	GetCardName(uint nInstance);
MAIV2DLL_EXPORT_CHAR	GetCardProducer(uint nInstance);
MAIV2DLL_EXPORT_CHAR	GetCardSeller(uint nInstance);
MAIV2DLL_EXPORT_CHAR	GetManufacture_Name(uint nInstance);
MAIV2DLL_EXPORT_CHAR	GetSerialNumber(uint nInstance);
MAIV2DLL_EXPORT_CHAR	GetCustomer_Name(uint nInstance);
MAIV2DLL_EXPORT_CHAR	GetCustomer_Number(uint nInstance);
MAIV2DLL_EXPORT_CHAR	GetCustomer_DateOfPurchase(uint nInstance);
MAIV2DLL_EXPORT		GetADChannels(uint nInstance);
MAIV2DLL_EXPORT		GetADChannelsNumberOfOversamplingModes(uint nInstance);
MAIV2DLL_EXPORT		GetADChannelsNumberOfGainModes(uint nInstance);
MAIV2DLL_EXPORT		GetADSampleWidth(uint nInstance);
MAIV2DLL_EXPORT		GetADSampleRate(uint nInstance);
MAIV2DLL_EXPORT		GetDAChannels(uint nInstance);
MAIV2DLL_EXPORT		GetDASampleWidth(uint nInstance);
MAIV2DLL_EXPORT		GetDASampleRate(uint nInstance);
MAIV2DLL_EXPORT		GetTTLChannels(uint nInstance);
MAIV2DLL_EXPORT		GetTTLSampleWidth(uint nInstance);
MAIV2DLL_EXPORT		GetTTLSampleRate(uint nInstance);
MAIV2DLL_EXPORT		GetCTChannels(uint nInstance);
MAIV2DLL_EXPORT		GetCTSampleWidth(uint nInstance);
MAIV2DLL_EXPORT		GetCTSampleRate(uint nInstance);
MAIV2DLL_EXPORT		GetPWMChannels(uint nInstance);
MAIV2DLL_EXPORT		GetPWMSampleWidth(uint nInstance);
MAIV2DLL_EXPORT		GetPWMSampleRate(uint nInstance);
MAIV2DLL_EXPORT		GetSoftwareExtension(uint nInstance, uint * pSWExtension);
MAIV2DLL_EXPORT		GetHardwareExtension(uint nInstance, uint * pHWExtension);

MAIV2DLL_EXPORT		GetMeasurementProcessorVersion(uint nInstance);
MAIV2DLL_EXPORT		GetControllerFirmwareVersion(uint nInstance);
MAIV2DLL_EXPORT		GetSystemDriverVersion(uint nInstance, char DLLVersion[]);
MAIV2DLL_EXPORT		PrivateFlashDataRead(uint nInstance, uchar PrivateData[], uint nLength);
MAIV2DLL_EXPORT		PrivateFlashDataWrite(uint nInstance, uchar PrivateData[], uint nLength);
MAIV2DLL_EXPORT		PrivateFlashDataClear(uint nInstance);

MAIV2DLL_EXPORT		SetLEDs(uint nInstance,bool AIRedOrFirstLEDOn,bool AIGreenOrSecondLEDOn,bool AIThirdLEDOn);

MAIV2DLL_EXPORT_CHAR	GetDLLVersion();
MAIV2DLL_EXPORT_CHAR	GetLIBVersion();
MAIV2DLL_EXPORT		GetCardIDBySerial(char Serial[], uint * nCardID);
MAIV2DLL_EXPORT		GetDeviceInfo(uint nCardID, int * nDeviceType, char Serial[]);


MAIV2DLL_EXPORT		GetNumberOfBurstsOnADController(uint nCardID, uint * nNumberOfBursts);
MAIV2DLL_EXPORT		GetNumberOfBurstsOnCTController(uint nCardID, uint * nNumberOfBursts);
MAIV2DLL_EXPORT		AlteraRegisterRead(uint nCardID, int   nAdress,  uint * nRegisterValue);
MAIV2DLL_EXPORT		AlteraRegisterWrite(uint nCardID, int   nAdress,  uint  nRegisterValue);

//MAIV2DLL_EXPORT		InternalFlashDataRead(uint nInstance, uint EEPromOffsetStart, uchar PrivateData[], uint nLength);
//MAIV2DLL_EXPORT		InternalFlashDataWrite(uint nInstance, uint EEPromOffsetStart, uchar PrivateData[], uint nLength);
//MAIV2DLL_EXPORT		InternalFlashDataClear(uint nInstance, uint EEPromOffsetStart);








// speziell für AgilentVEE
//MAIV2DLL_EXPORT SplitChannelList(char * pchInputString, uint dwInputStringSize, uint * pdwOutputArray, uint dwOutputArraySize, uint * dwNumberOfChannels);






////////////////////////////////////////////////////////////////////////////////////////////////////
/// <category>	Device Pool Funktionen. </category>
/// <categoryE>	device pool functions. </categoryE>
///
///
/// <filesummary>	zur Geräteübergreifenden Steuerung stehen diese Funktionen zur Verfügung: </filesummary>
/// <filesummaryE>	Functions that apply to all devices are: </filesummaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////


//MAIV2DLL_EXPORT UnloadDevicePool();
MAIV2DLL_EXPORT GetFirstDevice();
MAIV2DLL_EXPORT GetNumberOfDevices();
MAIV2DLL_EXPORT GetDeviceHandles(uint AODeviceIndices[], uint* ARLength);
MAIV2DLL_EXPORT GetFirstDeviceByType(uint DeviceType);
MAIV2DLL_EXPORT OpenDevice(uint nInstance);
MAIV2DLL_EXPORT CloseDevice(uint nInstance);
MAIV2DLL_EXPORT IsDeviceOpen(uint nInstance);
MAIV2DLL_EXPORT GetErrorDescription(uint nInstance, long ErrorNumber, char ErrorDescription[]);
MAIV2DLL_EXPORT SetGPCIFile(const char AIFilePath[], uint nLength);
MAIV2DLL_EXPORT_CHAR GetGPCIFilePath();

MAIV2DLL_EXPORT SetMAIDevicelistChangedHandler(MAI_DEVICELISTCHANGED_CALLBACK AIMAIDevicelistChangedFunction);

MAIV2DLL_EXPORT ReCreateDeviceListOmittingDeviceTypes(bool AICreatePCI,bool AICreateUSBMC4, bool CreateUSBBasic);
MAIV2DLL_EXPORT ShowMessageBoxOnDeviceCreationError(bool AIShowMsgBox);




////////////////////////////////////////////////////////////////////////////////////////////////////
/// <category>	PWM-Funktionen. </category>
/// <categoryE>	PWM functions. </categoryE>
///
///
/// <filesummary>	zur Steuerung bzw. Messung der PWM Kanäle stehen die folgenden Funktionne zur Verfügung:. </filesummary>
/// <filesummaryE>	for controlling and measuring PWM Channels these functions are available: </filesummaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
MAIV2DLL_EXPORT PWM_StartOutput(uint nInstance);
MAIV2DLL_EXPORT PWM_StopOutput(uint nInstance);
MAIV2DLL_EXPORT PWM_PreparePWMOutput(uint nInstance, uint nChannel, uint StartFrequency, uint nStartRatio);
MAIV2DLL_EXPORT PWM_PrepareFMOutput(uint nInstance, uint nChannel, uint StartFrequency, uint nPulsWidthRatio);
MAIV2DLL_EXPORT PWM_WriteNewPWMRatio(uint nInstance, uint nChannel, uint nRatio);
MAIV2DLL_EXPORT PWM_WriteNewFMFrequency(uint nInstance, uint nChannel, uint Frequency);
MAIV2DLL_EXPORT PWM_GetPWMRatio(uint nInstance, uint nChannel, uint* nRatio);
MAIV2DLL_EXPORT PWM_GetFMFrequency(uint nInstance, uint nChannel, uint* Frequency);






////////////////////////////////////////////////////////////////////////////////////////////////////
/// <category>	Online-Funktionen. </category>
/// <categoryE>	online functions. </categoryE>
///
///
/// <filesummary>	bei DSP-Karten, bei denen die jeweilige Online Funktion freigeschaltet ist,
/// 				stehen diese Funktionen zur Steuerung zur Verfügung </filesummary>
/// <filesummaryE>	for DSP cards, which have installed the corresponding online functions, these
/// 				functions are available: </filesummaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////


MAIV2DLL_EXPORT Realtime_AddTriggerEntry(uint nInstance, uint nChannelListEntry, uint nStartTriggerAktiv, double dStartSchwellwert1, double dStartSchwellwert2,
                                         uint nStartTriggerTyp, uint nStartEnableAtStart, uint nStartTriggerMessung, uint nStartTriggerSetTTL, uint nStartTriggerTTLKlemme,
                                         uint nStartTriggerTTLZustand, uint nStartTriggerTTLFlanke, uint nStopTriggerAktiv, double dStopSchwellwert1, double dStopSchwellwert2,
                                         uint nStopTriggerTyp, uint nStopEnableAtStart, uint nStopTriggerMessung, uint nStopTriggerSetTTL, uint nStopTriggerTTLKlemme,
                                         uint nStopTriggerTTLZustand, uint nStopTriggerTTLFlanke, uint nRetriggerbar, uint* AOIndexInChannelsRTList);

MAIV2DLL_EXPORT Realtime_AddFilterEntry(uint nInstance, uint AIChannelListEntry, uint AIFilterMode, uint AIFilterOrder, double AICoefficients[], double AIOutputGainFactor, uint* AOIndexIndChannelsRTList);

MAIV2DLL_EXPORT Realtime_DesignIIRFilter( double AISampleRate, uint AIFilterType, double AICutoffFreqency, double AICutoffFreqency2,  bool AIFrequenciesAreNormalized,
                                         double AIPassabsorbtion, double AIStopbandattenuation,
                                         uint AIDesignMethod, uint AIOrder,
                                         // Ausgabe:
                                         uint* AOFilterMode, double AOCoefficientsList[], double* AOGain );

MAIV2DLL_EXPORT Realtime_DesignFIRFilter(  double AISampleRate, uint AIFilterType, double AICutoffFreqLow, double AICutoffFreqHigh,  bool AIFrequenciesAreNormalized,
                                         uint AIOrder, uint AIFilterWindow, double AIWindowParameter,bool AIScalePassband,
                                         // Ausgabe:
                                         uint* AOFilterMode, double AOCoefficientsList[]);

MAIV2DLL_EXPORT Realtime_AddPIDEntry(uint nInstance, uint nChannelListEntry, double dPAnteil, double dIAnteil, double dDAnteil, uint nReglerArt, double Gain, double dSollwert, double dMinValue, double dMaxValue, uint nDAKanal, double nSampleFreq, uint* AOIndexInChannelsRTList);

MAIV2DLL_EXPORT Realtime_ChangePID_Params(uint nInstance, uint nChannelListEntry, uint nIndexInChannelsRTList ,double dPAnteil, double dIAnteil, double dDAnteil);

MAIV2DLL_EXPORT Realtime_ChangePID_NominalValue(uint nInstance, uint nChannelListEntry, uint nIndexInChannelsRTList ,double dSollwert);

MAIV2DLL_EXPORT Realtime_AddFFTEntry(uint nInstance, uint nChannelListEntry, uint nAnzahlPunkte, uint nSpektrum, double dGain, uint nFensterFunktion, double dParameter, uint* AOIndexInChannelsRTList);

MAIV2DLL_EXPORT Realtime_FFT_ReadData(uint nInstance, uint nChannelListEntry, double FFTData[], uint * nNumberOfValues);





////////////////////////////////////////////////////////////////////////////////////////////////////
/// <category>	SSI-Funktionen. </category>
/// <categoryE>	SSI functions. </categoryE>
///
///
/// <filesummary>	zur Steuerung bzw. Messung der SSI Kanäle stehen die folgenden Funktionne zur Verfügung:. </filesummary>
/// <filesummaryE>	for controlling and measuring SSI Channels these functions are available: </filesummaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
MAIV2DLL_EXPORT SSI_SetBitWidth(uint nInstance, uint nBitWidth);
MAIV2DLL_EXPORT SSI_ConfigSSI(uint nInstance, uint nReset, uint nResetEdge, uint nActivePassiveMode, uint nClockFrequency, uint nEdge);





////////////////////////////////////////////////////////////////////////////////////////////////////
/// <category>	TTL-Funktionen. </category>
/// <categoryE>	TTL functions. </categoryE>
///
///
/// <filesummary>	zur Steuerung bzw. Messung der TTL Kanäle stehen die folgenden Funktionne zur Verfügung:. </filesummary>
/// <filesummaryE>	for controlling and measuring TTL Channels these functions are available: </filesummaryE>
////////////////////////////////////////////////////////////////////////////////////////////////////
MAIV2DLL_EXPORT TTL_ClearChannelList(uint nInstance);
MAIV2DLL_EXPORT TTL_AddChannelToList(uint nInstance, uint nChannel, bool bToADList, uint nDigitalType);
MAIV2DLL_EXPORT TTL_GetChannelListSize(uint nInstance, uint * nCLSize);
MAIV2DLL_EXPORT TTL_SetFrequency(uint nInstance, double fFrequency);
MAIV2DLL_EXPORT TTL_SetChannelDirection(uint nInstance, uint nChannel, uint nDirectionValue);
MAIV2DLL_EXPORT TTL_GetChannelDirection(uint nInstance, uint nChannel, uint * nDirection);
MAIV2DLL_EXPORT TTL_ReadData(uint nInstance, uint pBuffer[], uint * nNumberOfBursts, uint bPartBlock, uint bSkipData);
MAIV2DLL_EXPORT TTL_ReadData8(uint nInstance, uchar* pBuffer, uint * nNUmberOfBursts);
MAIV2DLL_EXPORT TTL_ReadData16(uint nInstance, ushort* pBuffer, uint * nNUmberOfBursts);
MAIV2DLL_EXPORT TTL_ReadData32(uint nInstance, uint* pBuffer, uint * nNUmberOfBursts);
MAIV2DLL_EXPORT TTL_ReadData64(uint nInstance, u64* pBuffer, uint * nNUmberOfBursts);
MAIV2DLL_EXPORT TTL_GetBurstSize(uint nInstance, uint* nBurstSizeInBytes);
MAIV2DLL_EXPORT TTL_ReadDataExt(uint nInstance, uchar* pBuffer, uint * nNUmberOfBursts, uint nBurstSizeInBytes, __int64* AODateTimeT0, double* AODateTimeDeltaT);
MAIV2DLL_EXPORT TTL_ReadPort(uint nInstance, uint nPort, uint * nPortValue);
MAIV2DLL_EXPORT TTL_WritePort(uint nInstance, uint nPort, uint nPortValue);
MAIV2DLL_EXPORT TTL_ReadBit(uint nInstance, uint nChannel, uint * nBit);
MAIV2DLL_EXPORT TTL_WriteBit(uint nInstance, uint nChannel, uint nBit);
MAIV2DLL_EXPORT TTL_GetStreamPipeLevel(uint nInstance, double * fStreamPipeLevel);
MAIV2DLL_EXPORT TTL_GetNumberOfValues(uint nInstance, uint * nNumberOfValues);
MAIV2DLL_EXPORT TTL_InitializeTargetSettings(uint nInstance);
MAIV2DLL_EXPORT TTL_StartMeasure(uint nInstance);
MAIV2DLL_EXPORT TTL_StopMeasure(uint nInstance);
MAIV2DLL_EXPORT TTL_GetPortInfos(uint nInstance, uint * NumberOfPorts, uint * PortWidth, uint * NumberOfDigIn, uint * NumberOfDigOut);

#ifdef __cplusplus
}
#endif


#endif


